
-----------------------------------------------------------------------------
-- XoneDbFolder
-----------------------------------------------------------------------------
drop table XoneDbFolder;

CREATE TABLE XoneDbFolder
(
                        FolderId INTEGER NOT NULL,
                        ParentId INTEGER NOT NULL,
                        Name VARCHAR (128) NOT NULL,
                        Type VARCHAR (32) default 'Folder' NOT NULL,
                        ClassName VARCHAR (32) default '',
                        Timestamp TIMESTAMP NOT NULL,
                        Status VARCHAR (1) default 'U' NOT NULL,
                        LockUserId INTEGER,
                        Description VARCHAR (255),
                        Hint VARCHAR (255),
                        OwnerId INTEGER NOT NULL,
                        OwnerRead VARCHAR (1) default 'T' NOT NULL,
                        OwnerWrite VARCHAR (1) default 'T' NOT NULL,
                        GroupRead VARCHAR (1) default 'T' NOT NULL,
                        GroupWrite VARCHAR (1) default 'T' NOT NULL,
                        OtherRead VARCHAR (1) default 'F' NOT NULL,
                        OtherWrite VARCHAR (1) default 'F' NOT NULL,
    UNIQUE (Name, ParentId)
);

ALTER TABLE XoneDbFolder
    ADD PRIMARY KEY (FolderId);




-----------------------------------------------------------------------------
-- XoneDbObject
-----------------------------------------------------------------------------
drop table XoneDbObject;

CREATE TABLE XoneDbObject
(
                        ObjectId INTEGER NOT NULL,
                        FolderId INTEGER NOT NULL,
                        Name VARCHAR (128) NOT NULL,
                        Type VARCHAR (32) NOT NULL,
                        ClassName VARCHAR (255),
                        Timestamp TIMESTAMP NOT NULL,
                        Status VARCHAR (1) default 'U' NOT NULL,
                        LockUserId INTEGER,
                        Hint VARCHAR (255),
                        Elements CLOB(1G),
    UNIQUE (Name, FolderId)
);

ALTER TABLE XoneDbObject
    ADD PRIMARY KEY (ObjectId);




-----------------------------------------------------------------------------
-- XoneDbSession
-----------------------------------------------------------------------------
drop table XoneDbSession;

CREATE TABLE XoneDbSession
(
                        DbSessionId INTEGER NOT NULL,
                        UserId INTEGER NOT NULL,
                        SessionId VARCHAR (128) NOT NULL,
                        LoginTime TIMESTAMP NOT NULL,
                        SessionUpdateTime TIMESTAMP NOT NULL,
    UNIQUE (SessionId)
);

ALTER TABLE XoneDbSession
    ADD PRIMARY KEY (DbSessionId);




-----------------------------------------------------------------------------
-- XoneDbUser
-----------------------------------------------------------------------------
drop table XoneDbUser;

CREATE TABLE XoneDbUser
(
                        UserId INTEGER NOT NULL,
                        Name VARCHAR (128) NOT NULL,
                        Password VARCHAR (128) NOT NULL,
                        NickName VARCHAR (8),
                        DefaultGroupId INTEGER NOT NULL,
                        Role VARCHAR (32) default 'User',
                        Description VARCHAR (255),
    UNIQUE (Name)
);

ALTER TABLE XoneDbUser
    ADD PRIMARY KEY (UserId);




-----------------------------------------------------------------------------
-- XoneDbGroup
-----------------------------------------------------------------------------
drop table XoneDbGroup;

CREATE TABLE XoneDbGroup
(
                        GroupId INTEGER NOT NULL,
                        Name VARCHAR (128) NOT NULL,
                        Description VARCHAR (255),
    UNIQUE (Name)
);

ALTER TABLE XoneDbGroup
    ADD PRIMARY KEY (GroupId);




-----------------------------------------------------------------------------
-- XoneDbUserGroup
-----------------------------------------------------------------------------
drop table XoneDbUserGroup;

CREATE TABLE XoneDbUserGroup
(
                        UserGroupId INTEGER NOT NULL,
                        UserId INTEGER NOT NULL,
                        GroupId INTEGER NOT NULL,
    UNIQUE (UserId, GroupId)
);

ALTER TABLE XoneDbUserGroup
    ADD PRIMARY KEY (UserGroupId);




-----------------------------------------------------------------------------
-- XoneDbFolder: FOREIGN KEYS
-----------------------------------------------------------------------------
ALTER TABLE XoneDbFolder
    ADD CONSTRAINT XoneDbFolder_FK_1 FOREIGN KEY (OwnerId)
    REFERENCES XoneDbUser (UserId)
;


-----------------------------------------------------------------------------
-- XoneDbObject: FOREIGN KEYS
-----------------------------------------------------------------------------
ALTER TABLE XoneDbObject
    ADD CONSTRAINT XoneDbObject_FK_1 FOREIGN KEY (FolderId)
    REFERENCES XoneDbFolder (FolderId)
;


-----------------------------------------------------------------------------
-- XoneDbSession: FOREIGN KEYS
-----------------------------------------------------------------------------
ALTER TABLE XoneDbSession
    ADD CONSTRAINT XoneDbSession_FK_1 FOREIGN KEY (UserId)
    REFERENCES XoneDbUser (UserId)
;


-----------------------------------------------------------------------------
-- XoneDbUser: FOREIGN KEYS
-----------------------------------------------------------------------------
ALTER TABLE XoneDbUser
    ADD CONSTRAINT XoneDbUser_FK_1 FOREIGN KEY (DefaultGroupId)
    REFERENCES XoneDbGroup (GroupId)
;


-----------------------------------------------------------------------------
-- XoneDbGroup: FOREIGN KEYS
-----------------------------------------------------------------------------


-----------------------------------------------------------------------------
-- XoneDbUserGroup: FOREIGN KEYS
-----------------------------------------------------------------------------
ALTER TABLE XoneDbUserGroup
    ADD CONSTRAINT XoneDbUserGro_FK_1 FOREIGN KEY (UserId)
    REFERENCES XoneDbUser (UserId)
;
ALTER TABLE XoneDbUserGroup
    ADD CONSTRAINT XoneDbUserGro_FK_2 FOREIGN KEY (GroupId)
    REFERENCES XoneDbGroup (GroupId)
;

-----------------------------------------------------------------------------
-- SEQUENCE
-----------------------------------------------------------------------------

drop SEQUENCE XoneDbFolder_SEQ;
CREATE SEQUENCE XoneDbFolder_SEQ AS INT
   START WITH 1
   INCREMENT BY 1
   MINVALUE 1
   NO MAXVALUE
   NO CYCLE
   NO CACHE
   ORDER
;

drop SEQUENCE XoneDbObject_SEQ;
CREATE SEQUENCE XoneDbObject_SEQ AS INT
   START WITH 1
   INCREMENT BY 1
   MINVALUE 1
   NO MAXVALUE
   NO CYCLE
   NO CACHE
   ORDER
;

drop SEQUENCE XoneDbSession_SEQ;
CREATE SEQUENCE XoneDbSession_SEQ AS INT
   START WITH 1
   INCREMENT BY 1
   MINVALUE 1
   NO MAXVALUE
   NO CYCLE
   NO CACHE
   ORDER
;

drop SEQUENCE XoneDbUser_SEQ;
CREATE SEQUENCE XoneDbUser_SEQ AS INT
   START WITH 1
   INCREMENT BY 1
   MINVALUE 1
   NO MAXVALUE
   NO CYCLE
   NO CACHE
   ORDER
;

drop SEQUENCE XoneDbGroup_SEQ;
CREATE SEQUENCE XoneDbGroup_SEQ AS INT
   START WITH 1
   INCREMENT BY 1
   MINVALUE 1
   NO MAXVALUE
   NO CYCLE
   NO CACHE
   ORDER
;

drop SEQUENCE XoneDbUserGroup_SEQ;
CREATE SEQUENCE XoneDbUserGroup_SEQ AS INT
   START WITH 1
   INCREMENT BY 1
   MINVALUE 1
   NO MAXVALUE
   NO CYCLE
   NO CACHE
   ORDER
;

