
/* ---------------------------------------------------------------------- */
/* XoneDbFolder                                                      */
/* ---------------------------------------------------------------------- */

IF EXISTS (SELECT 1 FROM sysobjects WHERE type ='RI' AND name='XoneDbFolder_FK_1')
    ALTER TABLE XoneDbFolder DROP CONSTRAINT XoneDbFolder_FK_1;
IF EXISTS (SELECT 1 FROM sysobjects WHERE type = 'U' AND name = 'XoneDbFolder')
BEGIN
     DECLARE @reftable_1 nvarchar(60), @constraintname_1 nvarchar(60)
     DECLARE refcursor CURSOR FOR
     select reftables.name tablename, cons.name constraintname
      from sysobjects tables,
           sysobjects reftables,
           sysobjects cons,
           sysreferences ref
       where tables.id = ref.rkeyid
         and cons.id = ref.constid
         and reftables.id = ref.fkeyid
         and tables.name = 'XoneDbFolder'
     OPEN refcursor
     FETCH NEXT from refcursor into @reftable_1, @constraintname_1
     while @@FETCH_STATUS = 0
     BEGIN
       exec ('alter table '+@reftable_1+' drop constraint '+@constraintname_1)
       FETCH NEXT from refcursor into @reftable_1, @constraintname_1
     END
     CLOSE refcursor
     DEALLOCATE refcursor
     DROP TABLE XoneDbFolder
END


CREATE TABLE XoneDbFolder
(
                    FolderId INT IDENTITY (1, 1) NOT NULL,
                    ParentId INT NOT NULL,
                    Name VARCHAR (128) COLLATE Japanese_BIN NOT NULL,
                    Type VARCHAR (32)  COLLATE Japanese_BIN default 'Folder' NOT NULL,
                    ClassName VARCHAR (32)  COLLATE Japanese_BIN default '' NULL,
                    Timestamp DATETIME NOT NULL,
                    Status CHAR (1) default 'U' NOT NULL,
                    LockUserId INT NULL,
                    Description VARCHAR (255) NULL,
                    Hint VARCHAR (255) NULL,
                    OwnerId INT NOT NULL,
                    OwnerRead CHAR (1) default 'T' NOT NULL,
                    OwnerWrite CHAR (1) default 'T' NOT NULL,
                    GroupRead CHAR (1) default 'T' NOT NULL,
                    GroupWrite CHAR (1) default 'T' NOT NULL,
                    OtherRead CHAR (1) default 'F' NOT NULL,
                    OtherWrite CHAR (1) default 'F' NOT NULL,

    CONSTRAINT XoneDbFolder_PK PRIMARY KEY(FolderId),
    UNIQUE (Name, ParentId));





/* ---------------------------------------------------------------------- */
/* XoneDbObject                                                      */
/* ---------------------------------------------------------------------- */

IF EXISTS (SELECT 1 FROM sysobjects WHERE type ='RI' AND name='XoneDbObject_FK_1')
    ALTER TABLE XoneDbObject DROP CONSTRAINT XoneDbObject_FK_1;
IF EXISTS (SELECT 1 FROM sysobjects WHERE type = 'U' AND name = 'XoneDbObject')
BEGIN
     DECLARE @reftable_2 nvarchar(60), @constraintname_2 nvarchar(60)
     DECLARE refcursor CURSOR FOR
     select reftables.name tablename, cons.name constraintname
      from sysobjects tables,
           sysobjects reftables,
           sysobjects cons,
           sysreferences ref
       where tables.id = ref.rkeyid
         and cons.id = ref.constid
         and reftables.id = ref.fkeyid
         and tables.name = 'XoneDbObject'
     OPEN refcursor
     FETCH NEXT from refcursor into @reftable_2, @constraintname_2
     while @@FETCH_STATUS = 0
     BEGIN
       exec ('alter table '+@reftable_2+' drop constraint '+@constraintname_2)
       FETCH NEXT from refcursor into @reftable_2, @constraintname_2
     END
     CLOSE refcursor
     DEALLOCATE refcursor
     DROP TABLE XoneDbObject
END


CREATE TABLE XoneDbObject
(
                    ObjectId INT IDENTITY (1, 1) NOT NULL,
                    FolderId INT NOT NULL,
                    Name VARCHAR (128)  COLLATE Japanese_BIN NOT NULL,
                    Type VARCHAR (32)  COLLATE Japanese_BIN NOT NULL,
                    ClassName VARCHAR (255)  COLLATE Japanese_BIN NULL,
                    Timestamp DATETIME NOT NULL,
                    Status CHAR (1) default 'U' NOT NULL,
                    LockUserId INT NULL,
                    Hint VARCHAR (255) NULL,
                    Elements TEXT NULL,

    CONSTRAINT XoneDbObject_PK PRIMARY KEY(ObjectId),
    UNIQUE (Name, FolderId));





/* ---------------------------------------------------------------------- */
/* XoneDbSession                                                      */
/* ---------------------------------------------------------------------- */

IF EXISTS (SELECT 1 FROM sysobjects WHERE type ='RI' AND name='XoneDbSession_FK_1')
    ALTER TABLE XoneDbSession DROP CONSTRAINT XoneDbSession_FK_1;
IF EXISTS (SELECT 1 FROM sysobjects WHERE type = 'U' AND name = 'XoneDbSession')
BEGIN
     DECLARE @reftable_3 nvarchar(60), @constraintname_3 nvarchar(60)
     DECLARE refcursor CURSOR FOR
     select reftables.name tablename, cons.name constraintname
      from sysobjects tables,
           sysobjects reftables,
           sysobjects cons,
           sysreferences ref
       where tables.id = ref.rkeyid
         and cons.id = ref.constid
         and reftables.id = ref.fkeyid
         and tables.name = 'XoneDbSession'
     OPEN refcursor
     FETCH NEXT from refcursor into @reftable_3, @constraintname_3
     while @@FETCH_STATUS = 0
     BEGIN
       exec ('alter table '+@reftable_3+' drop constraint '+@constraintname_3)
       FETCH NEXT from refcursor into @reftable_3, @constraintname_3
     END
     CLOSE refcursor
     DEALLOCATE refcursor
     DROP TABLE XoneDbSession
END


CREATE TABLE XoneDbSession
(
                    DbSessionId INT IDENTITY (1, 1) NOT NULL,
                    UserId INT NOT NULL,
                    SessionId VARCHAR (128) NOT NULL,
                    LoginTime DATETIME NOT NULL,
                    SessionUpdateTime DATETIME NOT NULL,

    CONSTRAINT XoneDbSession_PK PRIMARY KEY(DbSessionId),
    UNIQUE (SessionId));





/* ---------------------------------------------------------------------- */
/* XoneDbUser                                                      */
/* ---------------------------------------------------------------------- */

IF EXISTS (SELECT 1 FROM sysobjects WHERE type ='RI' AND name='XoneDbUser_FK_1')
    ALTER TABLE XoneDbUser DROP CONSTRAINT XoneDbUser_FK_1;
IF EXISTS (SELECT 1 FROM sysobjects WHERE type = 'U' AND name = 'XoneDbUser')
BEGIN
     DECLARE @reftable_4 nvarchar(60), @constraintname_4 nvarchar(60)
     DECLARE refcursor CURSOR FOR
     select reftables.name tablename, cons.name constraintname
      from sysobjects tables,
           sysobjects reftables,
           sysobjects cons,
           sysreferences ref
       where tables.id = ref.rkeyid
         and cons.id = ref.constid
         and reftables.id = ref.fkeyid
         and tables.name = 'XoneDbUser'
     OPEN refcursor
     FETCH NEXT from refcursor into @reftable_4, @constraintname_4
     while @@FETCH_STATUS = 0
     BEGIN
       exec ('alter table '+@reftable_4+' drop constraint '+@constraintname_4)
       FETCH NEXT from refcursor into @reftable_4, @constraintname_4
     END
     CLOSE refcursor
     DEALLOCATE refcursor
     DROP TABLE XoneDbUser
END


CREATE TABLE XoneDbUser
(
                    UserId INT IDENTITY (1, 1) NOT NULL,
                    Name VARCHAR (128)  COLLATE Japanese_BIN NOT NULL,
                    Password VARCHAR (128) NOT NULL,
                    NickName VARCHAR (8) NULL,
                    DefaultGroupId INT NOT NULL,
                    Role VARCHAR (32) default 'User' NULL,
                    Description VARCHAR (255) NULL,

    CONSTRAINT XoneDbUser_PK PRIMARY KEY(UserId),
    UNIQUE (Name));





/* ---------------------------------------------------------------------- */
/* XoneDbGroup                                                      */
/* ---------------------------------------------------------------------- */

IF EXISTS (SELECT 1 FROM sysobjects WHERE type = 'U' AND name = 'XoneDbGroup')
BEGIN
     DECLARE @reftable_5 nvarchar(60), @constraintname_5 nvarchar(60)
     DECLARE refcursor CURSOR FOR
     select reftables.name tablename, cons.name constraintname
      from sysobjects tables,
           sysobjects reftables,
           sysobjects cons,
           sysreferences ref
       where tables.id = ref.rkeyid
         and cons.id = ref.constid
         and reftables.id = ref.fkeyid
         and tables.name = 'XoneDbGroup'
     OPEN refcursor
     FETCH NEXT from refcursor into @reftable_5, @constraintname_5
     while @@FETCH_STATUS = 0
     BEGIN
       exec ('alter table '+@reftable_5+' drop constraint '+@constraintname_5)
       FETCH NEXT from refcursor into @reftable_5, @constraintname_5
     END
     CLOSE refcursor
     DEALLOCATE refcursor
     DROP TABLE XoneDbGroup
END


CREATE TABLE XoneDbGroup
(
                    GroupId INT IDENTITY (1, 1) NOT NULL,
                    Name VARCHAR (128)  COLLATE Japanese_BIN NOT NULL,
                    Description VARCHAR (255) NULL,

    CONSTRAINT XoneDbGroup_PK PRIMARY KEY(GroupId),
    UNIQUE (Name));





/* ---------------------------------------------------------------------- */
/* XoneDbUserGroup                                                      */
/* ---------------------------------------------------------------------- */

IF EXISTS (SELECT 1 FROM sysobjects WHERE type ='RI' AND name='XoneDbUserGroup_FK_1')
    ALTER TABLE XoneDbUserGroup DROP CONSTRAINT XoneDbUserGroup_FK_1;
IF EXISTS (SELECT 1 FROM sysobjects WHERE type ='RI' AND name='XoneDbUserGroup_FK_2')
    ALTER TABLE XoneDbUserGroup DROP CONSTRAINT XoneDbUserGroup_FK_2;
IF EXISTS (SELECT 1 FROM sysobjects WHERE type = 'U' AND name = 'XoneDbUserGroup')
BEGIN
     DECLARE @reftable_6 nvarchar(60), @constraintname_6 nvarchar(60)
     DECLARE refcursor CURSOR FOR
     select reftables.name tablename, cons.name constraintname
      from sysobjects tables,
           sysobjects reftables,
           sysobjects cons,
           sysreferences ref
       where tables.id = ref.rkeyid
         and cons.id = ref.constid
         and reftables.id = ref.fkeyid
         and tables.name = 'XoneDbUserGroup'
     OPEN refcursor
     FETCH NEXT from refcursor into @reftable_6, @constraintname_6
     while @@FETCH_STATUS = 0
     BEGIN
       exec ('alter table '+@reftable_6+' drop constraint '+@constraintname_6)
       FETCH NEXT from refcursor into @reftable_6, @constraintname_6
     END
     CLOSE refcursor
     DEALLOCATE refcursor
     DROP TABLE XoneDbUserGroup
END


CREATE TABLE XoneDbUserGroup
(
                    UserGroupId INT IDENTITY (1, 1) NOT NULL,
                    UserId INT NOT NULL,
                    GroupId INT NOT NULL,

    CONSTRAINT XoneDbUserGroup_PK PRIMARY KEY(UserGroupId),
    UNIQUE (UserId, GroupId));





/* ---------------------------------------------------------------------- */
/* XoneDbUserGroup                                                      */
/* ---------------------------------------------------------------------- */

BEGIN
ALTER TABLE XoneDbFolder
    ADD CONSTRAINT XoneDbFolder_FK_1 FOREIGN KEY (OwnerId)
    REFERENCES XoneDbUser (UserId)
END    
;




/* ---------------------------------------------------------------------- */
/* XoneDbFolder                                                      */
/* ---------------------------------------------------------------------- */

BEGIN
ALTER TABLE XoneDbObject
    ADD CONSTRAINT XoneDbObject_FK_1 FOREIGN KEY (FolderId)
    REFERENCES XoneDbFolder (FolderId)
END    
;




/* ---------------------------------------------------------------------- */
/* XoneDbObject                                                      */
/* ---------------------------------------------------------------------- */

BEGIN
ALTER TABLE XoneDbSession
    ADD CONSTRAINT XoneDbSession_FK_1 FOREIGN KEY (UserId)
    REFERENCES XoneDbUser (UserId)
END    
;




/* ---------------------------------------------------------------------- */
/* XoneDbSession                                                      */
/* ---------------------------------------------------------------------- */

BEGIN
ALTER TABLE XoneDbUser
    ADD CONSTRAINT XoneDbUser_FK_1 FOREIGN KEY (DefaultGroupId)
    REFERENCES XoneDbGroup (GroupId)
END    
;




/* ---------------------------------------------------------------------- */
/* XoneDbUser                                                      */
/* ---------------------------------------------------------------------- */




/* ---------------------------------------------------------------------- */
/* XoneDbGroup                                                      */
/* ---------------------------------------------------------------------- */

BEGIN
ALTER TABLE XoneDbUserGroup
    ADD CONSTRAINT XoneDbUserGroup_FK_1 FOREIGN KEY (UserId)
    REFERENCES XoneDbUser (UserId)
END    
;

BEGIN
ALTER TABLE XoneDbUserGroup
    ADD CONSTRAINT XoneDbUserGroup_FK_2 FOREIGN KEY (GroupId)
    REFERENCES XoneDbGroup (GroupId)
END    
;



