
# -----------------------------------------------------------------------
# XoneDbFolder
# -----------------------------------------------------------------------
drop table if exists XoneDbFolder;

CREATE TABLE XoneDbFolder
(
                            FolderId INTEGER NOT NULL AUTO_INCREMENT,
                    ParentId INTEGER NOT NULL,
                    Name VARCHAR (128) BINARY NOT NULL,
                    Type VARCHAR (32) BINARY default 'Folder' NOT NULL,
                    ClassName VARCHAR (32) BINARY default '',
                    Timestamp TIMESTAMP NOT NULL,
                    Status CHAR (1) default 'U' NOT NULL,
                    LockUserId INTEGER,
                    Description VARCHAR (255) BINARY,
                    Hint VARCHAR (255) BINARY,
                    OwnerId INTEGER NOT NULL,
                    OwnerRead CHAR (1) default 'T' NOT NULL,
                    OwnerWrite CHAR (1) default 'T' NOT NULL,
                    GroupRead CHAR (1) default 'T' NOT NULL,
                    GroupWrite CHAR (1) default 'T' NOT NULL,
                    OtherRead CHAR (1) default 'F' NOT NULL,
                    OtherWrite CHAR (1) default 'F' NOT NULL,
    PRIMARY KEY(FolderId),
    FOREIGN KEY (OwnerId) REFERENCES XoneDbUser (UserId),
    UNIQUE (Name, ParentId)
);

# -----------------------------------------------------------------------
# XoneDbObject
# -----------------------------------------------------------------------
drop table if exists XoneDbObject;

CREATE TABLE XoneDbObject
(
                            ObjectId INTEGER NOT NULL AUTO_INCREMENT,
                    FolderId INTEGER NOT NULL,
                    Name VARCHAR (128) BINARY NOT NULL,
                    Type VARCHAR (32) BINARY NOT NULL,
                    ClassName VARCHAR (255) BINARY,
                    Timestamp TIMESTAMP NOT NULL,
                    Status CHAR (1) default 'U' NOT NULL,
                    LockUserId INTEGER,
                    Hint VARCHAR (255) BINARY,
                    Elements LONGTEXT,
    PRIMARY KEY(ObjectId),
    FOREIGN KEY (FolderId) REFERENCES XoneDbFolder (FolderId),
    UNIQUE (Name, FolderId)
);

# -----------------------------------------------------------------------
# XoneDbSession
# -----------------------------------------------------------------------
drop table if exists XoneDbSession;

CREATE TABLE XoneDbSession
(
                            DbSessionId INTEGER NOT NULL AUTO_INCREMENT,
                    UserId INTEGER NOT NULL,
                    SessionId VARCHAR (128) NOT NULL,
                    LoginTime TIMESTAMP NOT NULL,
                    SessionUpdateTime TIMESTAMP NOT NULL,
    PRIMARY KEY(DbSessionId),
    FOREIGN KEY (UserId) REFERENCES XoneDbUser (UserId),
    UNIQUE (SessionId)
);

# -----------------------------------------------------------------------
# XoneDbUser
# -----------------------------------------------------------------------
drop table if exists XoneDbUser;

CREATE TABLE XoneDbUser
(
                            UserId INTEGER NOT NULL AUTO_INCREMENT,
                    Name VARCHAR (128) BINARY NOT NULL,
                    Password VARCHAR (128) BINARY NOT NULL,
                    NickName VARCHAR (8) BINARY,
                    DefaultGroupId INTEGER NOT NULL,
                    Role VARCHAR (32) BINARY default 'User',
                    Description VARCHAR (255) BINARY,
    PRIMARY KEY(UserId),
    FOREIGN KEY (DefaultGroupId) REFERENCES XoneDbGroup (GroupId),
    UNIQUE (Name)
);

# -----------------------------------------------------------------------
# XoneDbGroup
# -----------------------------------------------------------------------
drop table if exists XoneDbGroup;

CREATE TABLE XoneDbGroup
(
                            GroupId INTEGER NOT NULL AUTO_INCREMENT,
                    Name VARCHAR (128) BINARY NOT NULL,
                    Description VARCHAR (255) BINARY,
    PRIMARY KEY(GroupId),
    UNIQUE (Name)
);

# -----------------------------------------------------------------------
# XoneDbUserGroup
# -----------------------------------------------------------------------
drop table if exists XoneDbUserGroup;

CREATE TABLE XoneDbUserGroup
(
                            UserGroupId INTEGER NOT NULL AUTO_INCREMENT,
                    UserId INTEGER NOT NULL,
                    GroupId INTEGER NOT NULL,
    PRIMARY KEY(UserGroupId),
    FOREIGN KEY (UserId) REFERENCES XoneDbUser (UserId),
    FOREIGN KEY (GroupId) REFERENCES XoneDbGroup (GroupId),
    UNIQUE (UserId, GroupId)
);


ALTER TABLE XoneDbFolder TYPE=InnoDB;
ALTER TABLE XoneDbObject TYPE=InnoDB;
ALTER TABLE XoneDbSession TYPE=InnoDB;
ALTER TABLE XoneDbUser TYPE=InnoDB;
ALTER TABLE XoneDbGroup TYPE=InnoDB;
ALTER TABLE XoneDbUserGroup TYPE=InnoDB;
  
  
  
  
  
  
