
-----------------------------------------------------------------------------
-- XoneDbFolder
-----------------------------------------------------------------------------
DROP TABLE XoneDbFolder CASCADE CONSTRAINTS;
DROP SEQUENCE XoneDbFolder_SEQ;

CREATE TABLE XoneDbFolder
(
    FolderId NUMBER NOT NULL,
    ParentId NUMBER NOT NULL,
    Name VARCHAR2 (128) NOT NULL,
    Type VARCHAR2 (32) default 'Folder' NOT NULL,
    ClassName VARCHAR2 (32) default '',
    Timestamp DATE NOT NULL,
    Status CHAR (1) default 'U' NOT NULL,
    LockUserId NUMBER,
    Description VARCHAR2 (255),
    Hint VARCHAR2 (255),
    OwnerId NUMBER NOT NULL,
    OwnerRead CHAR (1) default 'T' NOT NULL,
    OwnerWrite CHAR (1) default 'T' NOT NULL,
    GroupRead CHAR (1) default 'T' NOT NULL,
    GroupWrite CHAR (1) default 'T' NOT NULL,
    OtherRead CHAR (1) default 'F' NOT NULL,
    OtherWrite CHAR (1) default 'F' NOT NULL,
    CONSTRAINT uniqueNamePid UNIQUE (Name, ParentId)
);

ALTER TABLE XoneDbFolder
    ADD CONSTRAINT XoneDbFolder_PK
PRIMARY KEY (FolderId);


CREATE SEQUENCE XoneDbFolder_SEQ INCREMENT BY 1 START WITH 1 NOMAXVALUE NOCYCLE NOCACHE ORDER;

-----------------------------------------------------------------------------
-- XoneDbObject
-----------------------------------------------------------------------------
DROP TABLE XoneDbObject CASCADE CONSTRAINTS;
DROP SEQUENCE XoneDbObject_SEQ;

CREATE TABLE XoneDbObject
(
    ObjectId NUMBER NOT NULL,
    FolderId NUMBER NOT NULL,
    Name VARCHAR2 (128) NOT NULL,
    Type VARCHAR2 (32) NOT NULL,
    ClassName VARCHAR2 (255),
    Timestamp DATE NOT NULL,
    Status CHAR (1) default 'U' NOT NULL,
    LockUserId NUMBER,
    Hint VARCHAR2 (255),
    Elements LONG,
    CONSTRAINT uniqueNameFid UNIQUE (Name, FolderId)
);

ALTER TABLE XoneDbObject
    ADD CONSTRAINT XoneDbObject_PK
PRIMARY KEY (ObjectId);


CREATE SEQUENCE XoneDbObject_SEQ INCREMENT BY 1 START WITH 1 NOMAXVALUE NOCYCLE NOCACHE ORDER;

-----------------------------------------------------------------------------
-- XoneDbSession
-----------------------------------------------------------------------------
DROP TABLE XoneDbSession CASCADE CONSTRAINTS;
DROP SEQUENCE XoneDbSession_SEQ;

CREATE TABLE XoneDbSession
(
    DbSessionId NUMBER NOT NULL,
    UserId NUMBER NOT NULL,
    SessionId VARCHAR2 (128) NOT NULL,
    LoginTime DATE NOT NULL,
    SessionUpdateTime DATE NOT NULL,
    CONSTRAINT uniqueSessionId UNIQUE (SessionId)
);

ALTER TABLE XoneDbSession
    ADD CONSTRAINT XoneDbSession_PK
PRIMARY KEY (DbSessionId);


CREATE SEQUENCE XoneDbSession_SEQ INCREMENT BY 1 START WITH 1 NOMAXVALUE NOCYCLE NOCACHE ORDER;

-----------------------------------------------------------------------------
-- XoneDbUser
-----------------------------------------------------------------------------
DROP TABLE XoneDbUser CASCADE CONSTRAINTS;
DROP SEQUENCE XoneDbUser_SEQ;

CREATE TABLE XoneDbUser
(
    UserId NUMBER NOT NULL,
    Name VARCHAR2 (128) NOT NULL,
    Password VARCHAR2 (128) NOT NULL,
    NickName VARCHAR2 (8),
    DefaultGroupId NUMBER NOT NULL,
    Role VARCHAR2 (32) default 'User',
    Description VARCHAR2 (255),
    CONSTRAINT uniqueUserName UNIQUE (Name)
);

ALTER TABLE XoneDbUser
    ADD CONSTRAINT XoneDbUser_PK
PRIMARY KEY (UserId);


CREATE SEQUENCE XoneDbUser_SEQ INCREMENT BY 1 START WITH 1 NOMAXVALUE NOCYCLE NOCACHE ORDER;

-----------------------------------------------------------------------------
-- XoneDbGroup
-----------------------------------------------------------------------------
DROP TABLE XoneDbGroup CASCADE CONSTRAINTS;
DROP SEQUENCE XoneDbGroup_SEQ;

CREATE TABLE XoneDbGroup
(
    GroupId NUMBER NOT NULL,
    Name VARCHAR2 (128) NOT NULL,
    Description VARCHAR2 (255),
    CONSTRAINT uniqueGroupName UNIQUE (Name)
);

ALTER TABLE XoneDbGroup
    ADD CONSTRAINT XoneDbGroup_PK
PRIMARY KEY (GroupId);


CREATE SEQUENCE XoneDbGroup_SEQ INCREMENT BY 1 START WITH 1 NOMAXVALUE NOCYCLE NOCACHE ORDER;

-----------------------------------------------------------------------------
-- XoneDbUserGroup
-----------------------------------------------------------------------------
DROP TABLE XoneDbUserGroup CASCADE CONSTRAINTS;
DROP SEQUENCE XoneDbUserGroup_SEQ;

CREATE TABLE XoneDbUserGroup
(
    UserGroupId NUMBER NOT NULL,
    UserId NUMBER NOT NULL,
    GroupId NUMBER NOT NULL,
    CONSTRAINT uniqueUidGid UNIQUE (UserId, GroupId)
);

ALTER TABLE XoneDbUserGroup
    ADD CONSTRAINT XoneDbUserGroup_PK
PRIMARY KEY (UserGroupId);


CREATE SEQUENCE XoneDbUserGroup_SEQ INCREMENT BY 1 START WITH 1 NOMAXVALUE NOCYCLE NOCACHE ORDER;
ALTER TABLE XoneDbFolder
    ADD CONSTRAINT XoneDbFolder_FK_1 FOREIGN KEY (OwnerId)
    REFERENCES XoneDbUser (UserId)
;



ALTER TABLE XoneDbObject
    ADD CONSTRAINT XoneDbObject_FK_1 FOREIGN KEY (FolderId)
    REFERENCES XoneDbFolder (FolderId)
;



ALTER TABLE XoneDbSession
    ADD CONSTRAINT XoneDbSession_FK_1 FOREIGN KEY (UserId)
    REFERENCES XoneDbUser (UserId)
;



ALTER TABLE XoneDbUser
    ADD CONSTRAINT XoneDbUser_FK_1 FOREIGN KEY (DefaultGroupId)
    REFERENCES XoneDbGroup (GroupId)
;





ALTER TABLE XoneDbUserGroup
    ADD CONSTRAINT XoneDbUserGroup_FK_1 FOREIGN KEY (UserId)
    REFERENCES XoneDbUser (UserId)
;

ALTER TABLE XoneDbUserGroup
    ADD CONSTRAINT XoneDbUserGroup_FK_2 FOREIGN KEY (GroupId)
    REFERENCES XoneDbGroup (GroupId)
;



