
-----------------------------------------------------------------------------
-- XoneDbFolder
-----------------------------------------------------------------------------
DROP TABLE XoneDbFolder;
DROP SEQUENCE XoneDbFolder_SEQ;

CREATE SEQUENCE XoneDbFolder_SEQ;

CREATE TABLE XoneDbFolder
(
                                    FolderId integer DEFAULT nextval('XoneDbFolder_SEQ') NOT NULL,
                                    ParentId integer NOT NULL,
                                    Name varchar (128) NOT NULL,
                                    Type varchar (32) default 'Folder' NOT NULL,
                                    ClassName varchar (32) default '',
                                    Timestamp timestamp NOT NULL,
                                    Status char (1) default 'U' NOT NULL,
                                    LockUserId integer,
                                    Description varchar (255),
                                    Hint varchar (255),
                                      -- REFERENCES XoneDbUser (UserId)
    OwnerId integer NOT NULL,
                                    OwnerRead char (1) default 'T' NOT NULL,
                                    OwnerWrite char (1) default 'T' NOT NULL,
                                    GroupRead char (1) default 'T' NOT NULL,
                                    GroupWrite char (1) default 'T' NOT NULL,
                                    OtherRead char (1) default 'F' NOT NULL,
                                    OtherWrite char (1) default 'F' NOT NULL,
    PRIMARY KEY (FolderId),
    CONSTRAINT uniqueNamePid UNIQUE (Name, ParentId)
);


-----------------------------------------------------------------------------
-- XoneDbObject
-----------------------------------------------------------------------------
DROP TABLE XoneDbObject;
DROP SEQUENCE XoneDbObject_SEQ;

CREATE SEQUENCE XoneDbObject_SEQ;

CREATE TABLE XoneDbObject
(
                                    ObjectId integer DEFAULT nextval('XoneDbObject_SEQ') NOT NULL,
                                      -- REFERENCES XoneDbFolder (FolderId)
    FolderId integer NOT NULL,
                                    Name varchar (128) NOT NULL,
                                    Type varchar (32) NOT NULL,
                                    ClassName varchar (255),
                                    Timestamp timestamp NOT NULL,
                                    Status char (1) default 'U' NOT NULL,
                                    LockUserId integer,
                                    Hint varchar (255),
                                    Elements text,
    PRIMARY KEY (ObjectId),
    CONSTRAINT uniqueNameFid UNIQUE (Name, FolderId)
);


-----------------------------------------------------------------------------
-- XoneDbSession
-----------------------------------------------------------------------------
DROP TABLE XoneDbSession;
DROP SEQUENCE XoneDbSession_SEQ;

CREATE SEQUENCE XoneDbSession_SEQ;

CREATE TABLE XoneDbSession
(
                                    DbSessionId integer DEFAULT nextval('XoneDbSession_SEQ') NOT NULL,
                                      -- REFERENCES XoneDbUser (UserId)
    UserId integer NOT NULL,
                                    SessionId varchar (128) NOT NULL,
                                    LoginTime timestamp NOT NULL,
                                    SessionUpdateTime timestamp NOT NULL,
    PRIMARY KEY (DbSessionId),
    CONSTRAINT uniqueSessionId UNIQUE (SessionId)
);


-----------------------------------------------------------------------------
-- XoneDbUser
-----------------------------------------------------------------------------
DROP TABLE XoneDbUser;
DROP SEQUENCE XoneDbUser_SEQ;

CREATE SEQUENCE XoneDbUser_SEQ;

CREATE TABLE XoneDbUser
(
                                    UserId integer DEFAULT nextval('XoneDbUser_SEQ') NOT NULL,
                                    Name varchar (128) NOT NULL,
                                    Password varchar (128) NOT NULL,
                                    NickName varchar (8),
                                      -- REFERENCES XoneDbGroup (GroupId)
    DefaultGroupId integer NOT NULL,
                                    Role varchar (32) default 'User',
                                    Description varchar (255),
    PRIMARY KEY (UserId),
    CONSTRAINT uniqueUserName UNIQUE (Name)
);


-----------------------------------------------------------------------------
-- XoneDbGroup
-----------------------------------------------------------------------------
DROP TABLE XoneDbGroup;
DROP SEQUENCE XoneDbGroup_SEQ;

CREATE SEQUENCE XoneDbGroup_SEQ;

CREATE TABLE XoneDbGroup
(
                                    GroupId integer DEFAULT nextval('XoneDbGroup_SEQ') NOT NULL,
                                    Name varchar (128) NOT NULL,
                                    Description varchar (255),
    PRIMARY KEY (GroupId),
    CONSTRAINT uniqueGroupName UNIQUE (Name)
);


-----------------------------------------------------------------------------
-- XoneDbUserGroup
-----------------------------------------------------------------------------
DROP TABLE XoneDbUserGroup;
DROP SEQUENCE XoneDbUserGroup_SEQ;

CREATE SEQUENCE XoneDbUserGroup_SEQ;

CREATE TABLE XoneDbUserGroup
(
                                    UserGroupId integer DEFAULT nextval('XoneDbUserGroup_SEQ') NOT NULL,
                                      -- REFERENCES XoneDbUser (UserId)
    UserId integer NOT NULL,
                                      -- REFERENCES XoneDbGroup (GroupId)
    GroupId integer NOT NULL,
    PRIMARY KEY (UserGroupId),
    CONSTRAINT uniqueUidGid UNIQUE (UserId, GroupId)
);


----------------------------------------------------------------------
-- XoneDbUserGroup                                                      
----------------------------------------------------------------------

ALTER TABLE XoneDbFolder
    ADD CONSTRAINT XoneDbFolder_FK_1 FOREIGN KEY (OwnerId)
    REFERENCES XoneDbUser (UserId)
;

----------------------------------------------------------------------
-- XoneDbFolder                                                      
----------------------------------------------------------------------

ALTER TABLE XoneDbObject
    ADD CONSTRAINT XoneDbObject_FK_1 FOREIGN KEY (FolderId)
    REFERENCES XoneDbFolder (FolderId)
;

----------------------------------------------------------------------
-- XoneDbObject                                                      
----------------------------------------------------------------------

ALTER TABLE XoneDbSession
    ADD CONSTRAINT XoneDbSession_FK_1 FOREIGN KEY (UserId)
    REFERENCES XoneDbUser (UserId)
;

----------------------------------------------------------------------
-- XoneDbSession                                                      
----------------------------------------------------------------------

ALTER TABLE XoneDbUser
    ADD CONSTRAINT XoneDbUser_FK_1 FOREIGN KEY (DefaultGroupId)
    REFERENCES XoneDbGroup (GroupId)
;

----------------------------------------------------------------------
-- XoneDbUser                                                      
----------------------------------------------------------------------


----------------------------------------------------------------------
-- XoneDbGroup                                                      
----------------------------------------------------------------------

ALTER TABLE XoneDbUserGroup
    ADD CONSTRAINT XoneDbUserGroup_FK_1 FOREIGN KEY (UserId)
    REFERENCES XoneDbUser (UserId)
;
ALTER TABLE XoneDbUserGroup
    ADD CONSTRAINT XoneDbUserGroup_FK_2 FOREIGN KEY (GroupId)
    REFERENCES XoneDbGroup (GroupId)
;
